@@ -556,8 +556,47 @@ schemes = {
     },
     'Behance': {
         'flags': ['behance.net', 'beconfig-store_state'],
-        'message': 'Cookies required, ensure you added --cookies "ilo0=1"',
-        'regex': r'{"id":(?P<uid>\d+),"first_name":"(?P<first_name>[^"]+)","last_name":"(?P<last_name>[^"]+)","username":"(?P<username>[^"]+)"',
+        'regex': r'<script type="application/json" id="beconfig-store_state">({.+?})</script>',
+        'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x['profile']['owner'],
+            json.dumps,
+        ],
+        'url_mutations': [
+            {
+                'from': r'https?://(www.)?behance.net/(?P<username>[^/]+).*',
+                'to': 'https://www.behance.net/{username}/appreciated',
+                'headers': {'Cookie': 'ilo0=true'},
+            }
+        ],
+        'fields': {
+            'uid': lambda x: x.get('id'),
+            'fullname': lambda x: x.get('display_name'),
+            'last_name': lambda x: x.get('last_name'),
+            'first_name': lambda x: x.get('first_name'),
+            'website': lambda x: x.get('website'),
+            'username': lambda x: x.get('username'),
+            'is_verified': lambda x: x.get('verified') == 1,
+            'teams': lambda x: x.get('teams'),
+            'bio': lambda x: x.get('about')[0]['value'],
+            'image': lambda x: x.get('images', {}).get('276'),
+            'image_bg': lambda x: x.get('banner_image_url'),
+            'company': lambda x: x.get('company'),
+            'city': lambda x: x.get('city'),
+            'country': lambda x: x.get('country'),
+            'location': lambda x: x.get('location'),
+            'created_at': lambda x: timestamp_to_datetime(x.get('created_on')),
+            'occupation': lambda x: x.get('occupation'),
+            'links': lambda x: [a['url'] for a in x.get('social_links')],
+            'twitter_username': lambda x: x.get('twitter', '').lstrip('@'),
+            'comments': lambda x: x['stats']['comments'],
+            'followers_count': lambda x: x['stats']['followers'],
+            'following_count': lambda x: x['stats']['following'],
+            'profile_views': lambda x: x['stats']['received_profile_views'],
+            'project_views': lambda x: x['stats']['views'],
+            'appreciations': lambda x: x['stats']['appreciations'],
+        }
     },
     'Blogger': {
         'flags': ['www.blogger.com/static', 'blogspot.com/feeds/posts'],
@@ -761,7 +800,7 @@ schemes = {
         'extract_json': True,
         'fields': {
             'steam_id': lambda x: x['steamid'],
-            'nickname': lambda x: x['personaname'],  # это не совсем имя, а ник
+            'nickname': lambda x: x['personaname'],
             'username': lambda x: [y for y in x['url'].split('/') if y][-1],
         }
     },
@@ -785,12 +824,9 @@ schemes = {
         'extract_json': True,
         'message': 'Run with auth cookies to get your ids.',
         'fields': {
-            # 'your_uid': lambda x: x[-2]['data'][0].get('id'),
-            # 'your_name': lambda x: x[-2]['data'][0].get('full_name'),
-            # 'your_username': lambda x: x[-2]['data'][0].get('username'),
             'uid': lambda x: x[-1]['data'][0]['id'],
             'name': lambda x: x[-1]['data'][0]['full_name'],
-            'username': lambda x: x[-1]['data'][0]['username'],
+            'username': lambda x: x[-1]['data'][0]['username'].lstrip('@'),
             'following_count': lambda x: x[-1]['data'][0]['followings_count'],
             'follower_count': lambda x: x[-1]['data'][0]['followers_count'],
             'is_verified': lambda x: x[-1]['data'][0]['verified'],
@@ -941,6 +977,8 @@ schemes = {
             'website': lambda x: x['website'],
             'links': lambda x: [y['value'] for y in x['socialLinks']],
             'tagline': lambda x: x['tagline'],
+            'image': lambda x: x['devidDeviation']['author']['usericon'],
+            'bio': lambda x: x['textContent']['excerpt'],
         }
     },
     'Flickr': {
@@ -991,6 +1029,11 @@ schemes = {
             'fullname': lambda x: x['campaign']['included'][0]['attributes']['full_name'],
             'links': lambda x: [y['attributes'].get('external_profile_url') for y in x['campaign']['included'] if
                                 y['attributes'].get('app_name')],
+            'image': lambda x: x['campaign']['data']['attributes']['avatar_photo_url'],
+            'image_bg': lambda x: x['campaign']['data']['attributes']['cover_photo_url'],
+            'is_nsfw': lambda x: x['campaign']['data']['attributes']['is_nsfw'],
+            'created_at': lambda x: x['campaign']['data']['attributes']['published_at'],
+            'bio': lambda x: x['campaign']['data']['attributes']['summary'],
         }
     },
     'Telegram': {
@@ -1012,17 +1055,18 @@ schemes = {
             json.dumps,
         ],
         'fields': {
-            'buzzfeed_id': lambda x: x['user_uuid'],
+            'uuid': lambda x: x['user_uuid'],
             'id': lambda x: x['user']['id'],
             'fullname': lambda x: x['user']['displayName'],
-            'buzzfeed_username': lambda x: x['user']['username'],
+            'username': lambda x: x['user']['username'],
             'bio': lambda x: x['user']['bio'],
-            'posts': lambda x: x['buzz_count'],
-            'memberSince': lambda x: timestamp_to_datetime(x['user']['memberSince']),
-            'isCommunityUser': lambda x: x['user']['isCommunityUser'],
-            'deleted': lambda x: x['user']['deleted'],
-            # 'social_names': lambda x: [y.get('name') for y in x['user']['social']],
+            'posts_count': lambda x: x['buzz_count'],
+            'created_at': lambda x: timestamp_to_datetime(x['user']['memberSince']),
+            'is_community_user': lambda x: x['user']['isCommunityUser'],
+            'is_deleted': lambda x: x['user']['deleted'],
             'social_links': lambda x: [y.get('url') for y in x['user']['social']],
+            'image': lambda x: 'https://img.buzzfeed.com/buzzfeed-static' + x['user']['image'],
+            'image_bg': lambda x: 'https://img.buzzfeed.com/buzzfeed-static' + x['user']['headerImage'],
         }
     },
     'Linktree': {
@@ -1086,6 +1130,8 @@ schemes = {
         'fields': {
             'fullname': lambda x: x.find('h1', {'class': 'blog-title'}).find('a').text,
             'title': lambda x: x.find('div', {'class': 'title-group'}).find('span', {'class': 'description'}).text.strip(),
+            'image': lambda x: x.find('a', {'class': 'user-avatar'}).find('img').get('src'),
+            'image_bg': lambda x: x.find('a', {'class': 'header-image'}).get('data-bg-image'),
             'links': lambda x: [enrich_link(a.find('a').get('href')) for a in x.find('div', {'class': 'nav-wrapper'}).find_all('li', {'class': 'nav-item nav-item--page'})],
         }
     },
@@ -1230,4 +1276,23 @@ schemes = {
             'links': lambda x: [a.get('href') for a in x.find('div', {'id': 'list_my-sites'}).find_all('a')] or None,
         },
     },
+    'tapd': {
+        'flags': ['{"_id"', 'userDetails":{"', '"sid":"'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'url_mutations': [
+            {
+                'from': r'https?://tapd.co/(?P<username>[^/]+).*',
+                'to': 'https://tapd.co/api/user/getPublicProfile/{username}',
+            }
+        ],
+        'fields': {
+            'fullname': lambda x: x['name'],
+            'username': lambda x: x['userDetails']['username'],
+            'bio': lambda x: x['bio'],
+            'views_count': lambda x: x['count'],
+            'image': lambda x: 'https://distro.tapd.co/' + x['header']['picture'],
+            'links': lambda x: [l['url'].strip() for l in x['links']],
+        }
+    }
 }
