@@ -17,7 +17,7 @@ def test_vk_user_profile_no_username():
     info = extract(parse('https://vk.com/id568161939')[0])
 
     assert info.get('vk_id') == '568161939'
-    assert info.get('vk_username') == None
+    assert info.get('vk_username') is None
     assert info.get('fullname') in ('Юля Заболотная', 'Yulya Zabolotnaya')
 
 
@@ -31,7 +31,7 @@ def test_vk_blocked_user_profile():
     headers = {'User-Agent': 'Curl'}
     info = extract(parse('https://vk.com/alexaimephotography', headers=headers)[0])
 
-    assert info.get('fullname') in ('Alex Aimé')
+    assert info.get('fullname') in 'Alex Aimé'
 
 
 def test_yandex_disk():
@@ -118,7 +118,7 @@ def test_habr_no_image():
 
     assert info.get('uid') == '1800409'
     assert info.get('username') == 'ne555'
-    assert not 'image' in info
+    assert 'image' not in info
 
 
 @pytest.mark.skip(reason="down")
@@ -128,10 +128,10 @@ def test_twitter_shadowban_no_account():
     assert info.get('has_tweets') == 'False'
     assert info.get('is_exists') == 'False'
     assert info.get('username') == 'sgfrgrrr'
-    assert not 'is_protected' in info
-    assert not 'has_ban' in info
-    assert not 'has_search_ban' in info
-    assert not 'has_banned_in_search_suggestions' in info
+    assert 'is_protected' not in info
+    assert 'has_ban' not in info
+    assert 'has_search_ban' not in info
+    assert 'has_banned_in_search_suggestions' not in info
 
 
 @pytest.mark.skip(reason="down")
@@ -225,6 +225,7 @@ def test_github_api():
     assert info.get('bio') == 'dev, infosec, osint'
     assert info.get('blog_url') == 'https://t.me/s/osint_mindset'
 
+
 def test_yandex_disk_photos():
     info = extract(parse('https://yadi.sk/a/oiySK_wg3Vv5p4')[0])
 
@@ -349,12 +350,29 @@ def test_yandex_bugbounty():
 
 
 def test_behance():
-    info = extract(parse('https://www.behance.net/Skyratov', 'ilo0=1')[0])
+    info = extract(parse('https://www.behance.net/patrickseymour', 'gpv=behance.net:profile:appreciated; ilo0=true')[0])
 
-    assert info.get('uid') == '39065909'
-    assert info.get('username') == 'Skyratov'
-    assert info.get('last_name') == 'Skuratov'
-    assert info.get('first_name') == 'Vasiliy'
+    assert info.get('uid') == '376641'
+    assert info.get('fullname') == 'Patrick Seymour'
+    assert info.get('last_name') == 'Seymour'
+    assert info.get('first_name') == 'Patrick'
+    assert info.get('username') == 'patrickseymour'
+    assert info.get('is_verified') == 'True'
+    assert info.get('bio') == 'False'
+    assert info.get('image') == 'https://mir-s3-cdn-cf.behance.net/user/276/012d0f376641.600ec6e15a5af.png'
+    assert info.get('city') == 'Montreal'
+    assert info.get('country') == 'Canada'
+    assert info.get('location') == 'Montreal, Quebec, Canada'
+    assert info.get('created_at') in ('2011-03-23 16:09:24', '2011-03-23 13:09:24')
+    assert info.get('occupation') == 'Freelancer Art director • Illustrator'
+    assert info.get('links') == "['http://twitter.com/PatrickSeymour', 'http://facebook.com/patrickseymourillustrateur', 'http://linkedin.com/in/patrick-seymour-70334b2b?trk=hp-identity-photo', 'http://vimeo.com/user9401948', 'http://pinterest.com/patrickseymour', 'http://instagram.com/patrickseymour']"
+    assert info.get('twitter_username') == 'PatrickSeymour'
+    assert 'comments' in info
+    assert 'followers_count' in info
+    assert 'following_count' in info
+    assert 'profile_views' in info
+    assert 'project_views' in info
+    assert 'appreciations' in info
 
 
 @pytest.mark.github_failed
@@ -365,8 +383,8 @@ def test_500px():
     assert info.get('legacy_id') == '23896'
     assert info.get('username') == 'The-Maksimov'
     assert info.get('name') == 'Maxim Maximov'
-    assert info.get('qq_uid') == None
-    assert info.get('fb_uid') == None
+    assert info.get('qq_uid') is None
+    assert info.get('fb_uid') is None
     assert info.get('instagram_username') == 'the.maksimov'
     assert info.get('twitter_username') == 'The_Maksimov'
     assert info.get('website') == 'www.instagram.com/the.maksimov'
@@ -515,6 +533,8 @@ def test_deviantart():
     assert info.get(
         'links') == "['https://www.instagram.com/muse.mercier/']"
     assert info.get('tagline') == 'Nothing worth having is easy...'
+    assert info.get('bio').startswith('Hi my name is Muse Mercier and welcome to my') is True
+    assert info.get('created_at') in ('2005-06-16 18:17:41', '2005-06-16 14:17:41')
 
 
 def test_tumblr():
@@ -523,6 +543,8 @@ def test_tumblr():
     assert info.get('fullname') == 'Alex Aimé Photography'
     assert info.get('title') == 'My name is Alex Aimé, and i am a freelance photographer. Originally from Burgundy in France .I am a man of 29 years. Follow me on : www.facebook.com/AlexAimePhotography/'
     assert info.get('links') == "['https://www.facebook.com/AlexAimePhotography/', 'https://500px.com/alexaimephotography', 'https://www.instagram.com/alexaimephotography/', 'https://www.flickr.com/photos/photoambiance/']"
+    assert 'image' in info
+    assert 'image_bg' in info
 
 
 def test_eyeem():
@@ -573,7 +595,7 @@ def test_pinterest_api():
     assert info.get('fullname') == 'Gergely Sándor-Szendrenyi'
     assert info.get('type') == 'user'
     assert info.get('image') == 'https://s.pinimg.com/images/user/default_280.png'
-    assert info.get('country') == None
+    assert info.get('country') is None
     assert info.get('is_indexed') == 'True'
     assert info.get('is_partner') == 'False'
     assert info.get('is_tastemaker') == 'False'
@@ -594,15 +616,15 @@ def test_pinterest_api():
 def test_pinterest_profile():
     info = extract(parse('https://www.pinterest.ru/gergelysndorszendrenyi/boards/')[0])
 
-    assert info.get('pinterest_id') == None
+    assert info.get('pinterest_id') is None
     assert info.get('pinterest_username') == 'gergelysndorszendrenyi'
     assert info.get('fullname') == 'Gergely Sándor-Szendrenyi'
-    assert info.get('type') == None
+    assert info.get('type') is None
     assert info.get('image') == 'https://s.pinimg.com/images/user/default_280.png'
     assert info.get('country') == 'HU'
     assert info.get('is_indexed') == 'True'
-    assert info.get('is_partner') == None
-    assert info.get('is_tastemaker') == None
+    assert info.get('is_partner') is None
+    assert info.get('is_tastemaker') is None
     assert info.get('is_indexed') == 'True'
     assert info.get('is_website_verified') == 'False'
     assert info.get('follower_count') == '2'
@@ -721,6 +743,11 @@ def test_patreon():
     assert info.get('patreon_username') == 'annetlovart'
     assert info.get('fullname') == 'Annet Lovart'
     assert info.get('links') == "['https://www.facebook.com/322598031832479', 'https://www.instagram.com/annet_lovart', 'https://twitter.com/annet_lovart', 'https://youtube.com/channel/UClDg4ntlOW_1j73zqSJxHHQ']"
+    assert info.get('is_nsfw') == 'False'
+    assert 'image' in info
+    assert 'image_bg' in info
+    assert info.get('created_at') == '2020-04-19T16:29:11.000+00:00'
+    assert 'bio' in info
 
 
 def test_last_fm():
@@ -797,7 +824,7 @@ def test_tproger():
     info = extract(parse('https://tproger.ru/author/NickPrice/')[0])
 
     assert info.get('fullname') == 'Никита Прияцелюк'
-    assert info.get('image').startswith('https://secure.gravatar.com/avatar/b6c7803b43433349ff84b11093562594') == True
+    assert info.get('image').startswith('https://secure.gravatar.com/avatar/b6c7803b43433349ff84b11093562594') is True
 
 
 def test_jsfiddle():
@@ -885,3 +912,28 @@ def test_uidme():
     assert info.get('skype') == 'Dariya Koshka'
     assert info.get('location') == 'Луганск'
     assert info.get('links') == "['http://www.proza.ru/avtor/dahakot']"
+
+
+def test_tapd():
+    info = extract(parse('https://tapd.co/api/user/getPublicProfile/betsyalvarezz')[0])
+
+    assert info.get('fullname') == 'Betsy Alvarez'
+    assert info.get('username') == 'betsyalvarezz'
+    assert int(info.get('views_count')) > 43124
+    assert info.get('image') == 'https://distro.tapd.co/x3fwD79IdB0LqOqf.jpeg'
+    assert info.get('links') == "['https://www.twitter.com/Betsyalvarezz', 'https://www.instagram.com/Betsyalvarezz', 'https://cash.app/$Betsyalvarezz', 'https://www.tiktok.com/@Betsyalvarezz', 'https://www.instagram.com/Brb.thelabel', 'https://www.youtube.com/c/BetsyAlvarezz', 'https://www.amazon.com/hz/wishlist/ls/2GNHXWNBBCIP0?ref_=wl_share', 'https://onlyfans.com/Betsyalvarezz']"
+
+
+def test_buzzfeed():
+    info = extract(parse('https://www.buzzfeed.com/lisa')[0])
+
+    assert info.get('uuid') == '408a7d54-6af9-452e-8614-7f44216ed983'
+    assert info.get('id') == '43876'
+    assert info.get('fullname') == 'lisa'
+    assert info.get('username') == 'lisa'
+    assert info.get('bio') == 'If I&#39;m not me than who am I? And if I&#39;m somebody else, than why do I look like me?'
+    assert info.get('posts_count') == '0'
+    assert info.get('created_at') in ('2009-12-17 23:47:09', '2009-12-17 20:47:09')
+    assert info.get('is_community_user') == 'True'
+    assert info.get('is_deleted') == 'False'
+    assert info.get('image') == 'https://img.buzzfeed.com/buzzfeed-static/static/user_images/web02/2009/12/17/20/lisa-31169-1261100831-63.jpg'
